#!/usr/bin/env python
import os
import sys

import matplotlib.image as mpimg
import nibabel as nib
import numpy as np
from scipy import ndimage

from utils import (add_gaussian_noise,
                   compare_image,
                   get_slice,
                   inverse_image,
                   non_lin_func_image,
                   split_name_with_nii)

MAX_INTENSITY_VALUE = 128
BLUR_SIGMA = 2

input_filename = sys.argv[1]
output_directory = sys.argv[2]

# Simple 2D example of 'image processing'
basename, extension = split_name_with_nii(sys.argv[1])
if extension in ['.png', 'jpeg']:
    data = mpimg.imread(sys.argv[1])
    if data.ndim == 3:
        data = np.average(data, axis=2)
elif extension in ['.nii', '.nii.gz']:
    nii_img = nib.load(sys.argv[1])
    data = get_slice(nii_img.get_data(), 'axial')

# Normalize
data = (data / np.max(data)) * MAX_INTENSITY_VALUE

# Add gaussian noise
noisy_data = add_gaussian_noise(data,
                                constrain_intensity=False, 
                                max_val=MAX_INTENSITY_VALUE)

# Multiplication & clipping
mult_data = np.clip(data * 1.5, 0, MAX_INTENSITY_VALUE)

# Gaussian blur
blur_data = ndimage.gaussian_filter(data, sigma=BLUR_SIGMA)

# Inverse intensities
inv_data = inverse_image(data)

# Apply function on intensities
func_data = non_lin_func_image(data)

if not os.path.isdir(output_directory):
    os.mkdir(output_directory)

# Pre-determine filename
filename_list = ['noisy.png', 'mult.png', 'blur.png', 'inv.png', 'func.png']
mod_data_list = [noisy_data, mult_data, blur_data, inv_data, func_data]

for i in range(len(filename_list)):
    if os.path.isfile(filename_list[i]):
        print(filename_list[i], 'already exist, overwritting')
    compare_image(data, mod_data_list[i],
                  filename=os.path.join(output_directory, filename_list[i]))
