#!/usr/bin/env python
import os
import sys

import matplotlib.image as mpimg
import nibabel as nib
import numpy as np
from scipy import signal

from utils import (save_animated_slices,
                   normalize_intensities,
                   split_name_with_nii)

AXIS_NAME = ['axial', 'sagittal', 'coronal']

input_filename = sys.argv[1]
choice_of_axis = sys.argv[2]
output_directory = sys.argv[3]

# Simplistic viewer for 3D NIFTI
basename, extension = split_name_with_nii(input_filename)
if extension in ['.nii', '.nii.gz']:
    img = nib.load(input_filename)
else:
    print(input_filename, 'is not a valid filename (NIFTI required)')

data = normalize_intensities(img.get_fdata(), 255)
# median_deta = median_filter(data)
median_deta = signal.medfilt(data, kernel_size=1)

if not os.path.isdir(output_directory):
    os.mkdir(output_directory)

if choice_of_axis == 'all':
    for axis in AXIS_NAME:
        save_animated_slices(median_deta,
                             axis_name=axis,
                             output_filename=os.path.join(output_directory,
                                                          '{0}.gif'.format(axis)))
else:
    save_animated_slices(median_deta,
                         axis_name=axis,
                         output_filename=os.path.join(output_directory,
                                                      '{0}.gif'.format(choice_of_axis)))
